La révolution d'un seul brin de paille
======================================

Ce livre par Masanobu Fukuoka est reconnu pour sa méthode d'agriculture
du "non-agir". Il ne s'agit pas de ne rien faire mais plutôt de
cultiver aussi simplement que possible dans l'environnement naturel,
et ce, en coopérant avec lui - ça sonne comme la permaculture?

Pour arriver à cette méthode, M. Fukuoaka se demande "Et si on ne faisant pas
ceci? Et si on ne faisant pas cela?" Finalement, il est arrivé à ces quatre
principes: ne pas cultiver; pas de fertilisant chimique ou de compost préparé;
ne pas désherber au cultivateur ni aux herbicides; pas de dependance envers
les produits chimiques.

Son plus grand succès avec cette méthode est de semer l'orge et le riz sur le
même champ en alternance, utilisant la paille d'orge pour couvrir le riz et la
paille de riz pour l'orge. Le trèfle blanc et les mauvaises herbes poussent
aussi librement dans le champs pour fixer l'azote. Il est possible que ce
n'était pas commun au Japon mais ça se fait en Europe depuis au moins 150 ans.

Ainsi, "M. Fukuoka récolte entre cinquante et soixante quintaux de riz à
l'hectare. Ce rendement est approximativement le même que celui produit tant
par la méthode chimique que traditionnelle dans sa région." Cependant,
beaucoup à changé depuis les années soixante-dix. Son rendement équivaut à
6t/ha tandis que la moyene en 2021 au Japon est de 7.5t/ha¹ - soit 25% de
plus.

M. Fukuoka prétend pousser ses récoltes "sans produit chimique d'aucune sorte"
mais il s'agit seulement de ses céréales tandis qu'il a occasionnellement
recours à une émulsion d'huile de machine pour contrôler la cochenille. Il
préconise aussi de vendre les fruits dans la région de production de manière à
éliminer le temps et la dépense exigés par l'expédition mais il ne s'empêche
pas de livrer jusqu'au quartier de Suginami à Tokyo car "le prix était
convenable".

À part les quelques contradictions, il abuse un peu de son autorité
scientifique ayant travaillé pour le Bureau des Douanes de Yokohama à la
Division de l'Inspection des Plantes. "Croire que par la recherche et
l'invention l'humanité peut créer quelque chose de mieux que la nature est une
illusion." Un chercheur ou un éleveur de plantes ne cherche à faire "mieux que
la nature" car la nature n'a pas de but - certainement pas le but de nourrire
l'homme. Il n'y a pas de "mieux" car il n'y pas de système de jugement. Il y a
cependant des compromis comme une plante qui perd des forces à résiter aux
champignons aura moins de forces pour produire des graines.

Et encore, "Les aliments qui se sont trop éloignés de leur état primitif et
ceux obtenus chimiquement ou dans un environnement entièrement aménagé,
déséquilibribrent la chimie du corps." Le blé (quelques fusions) et le colza
(croisement entre un chou et une navette) sont pourtant des graines créées par
l'homme. Et la banane sauvage est pratiquement inmangeable car elle est
surtout constitué de graines. Est-ce que mangé une banane désiquilibre la
chimie du corps? Qu'est-ce que ça veut même dire?

À part de l'agriculture et de la science, M. Fukuoka aborde aussi la
philosophie de la mort de l'égo. "Les hommes ne connaissent rien du tout. Il
n'y a pas de valeur intrinsèque dans quoi que ce soit, et chaque action est un
effort futile et sans signification." C'est cette pensé qui a complètement
changé l'auteur et l'a mis sur le chemain de la révolution d'un seul brin de
paille.

Au final, la méthode du "non-agir" a certainement une grande valeur mais le
contenu spécifique à l'agriculture est trop spécifique au Japon, certaines
références sont datées, certains commentaires scientifiques sont douteux et la
philosophie trop superficielle. Bref, je recommanderais seulementla première
partie du livre.

1. https://knoema.com/atlas/Japan/topics/Agriculture/Crops-Production-Yield/Paddy-rice-yield#:~:text=In%202021%2C%20paddy%20rice%20yield,hg%20per%20ha%20in%202021.
